/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.flume.tools;

import java.util.Locale;

/**
 * Utilities for platform & operating system detection
 */
public class PlatformDetect {

  /**
   * Detects whether we are running under Microsoft Windows.
   * @return true if and only if we are running on a Windows system.
   */
  public static boolean isWindows() {
    String os = System.getProperty("os.name");
    boolean isWin = (os.toLowerCase(Locale.ENGLISH).indexOf("win") >= 0);
    return isWin;
  }

}
